vfbLib.compilers.glyph.GlyphCompiler
====================================

.. currentmodule:: vfbLib.compilers.glyph

.. autoclass:: GlyphCompiler
   :members:
   :show-inheritance:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~GlyphCompiler.__init__
      ~GlyphCompiler.compile
      ~GlyphCompiler.compile_hex
      ~GlyphCompiler.merge
      ~GlyphCompiler.write_bytes
      ~GlyphCompiler.write_double
      ~GlyphCompiler.write_doubles
      ~GlyphCompiler.write_float
      ~GlyphCompiler.write_floats
      ~GlyphCompiler.write_int16
      ~GlyphCompiler.write_int32
      ~GlyphCompiler.write_str
      ~GlyphCompiler.write_uint16
      ~GlyphCompiler.write_uint32
      ~GlyphCompiler.write_uint8
      ~GlyphCompiler.write_value
   
   

   
   
   